==> nextcloud-31.0.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/de.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Teams",
    "You created the team {circle}" : "Du hast das Team {circle} erstellt",
    "{author} created the team {circle}" : "{author} hat das Team {circle} erstellt",
    "You deleted {circle}" : "Du hast {circle} gelöscht",
    "{author} deleted {circle}" : "{author} hat {circle} gelöscht",
    "You made {member} join {circle}" : "Du hast {member} {circle} beitreten lassen.",
    "{author} made {member} join {circle}" : "{author} hat {member} {circle} beitreten lassen",
    "You added team {member} as member to {circle}" : "Du hast das Team {member} als Mitglied zu {circle} hinzugefügt",
    "{author} added team {member} as member to {circle}" : "{author} hat das Team {member} als Mitglied zu {circle} hinzugefügt",
    "You made {member} leave {circle}" : "Du hast {member} aus {circle} entfernt",
    "{author} made {member} leave {circle}" : "{author} hat {member} aus {circle} entfernt",
    "You removed {member} from {circle}" : "Du hast {member} aus {circle} entfernt",
    "{author} removed {member} from {circle}" : "{author} hat {member} aus {circle} entfernt",
    "You joined {circle}" : "Du bist dem {circle} beigetreten",
    "{member} joined {circle}" : "{member} ist {circle} beigetreten",
    "You accepted the invitation to join {circle}" : "Du hast die Einladung angenommen {circle} beizutreten",
    "{member} accepted the invitation to join {circle}" : "{member} hat die Einladung angenommen {circle} beizutreten",
    "You added {member} as member to {circle}" : "Du hast {member} dem Kreis {circle} hinzugefügt",
    "You have been added as member to {circle} by {author}" : "Du wurdest von {author} als Mitglied zu {circle} hinzugefügt",
    "{member} has been added as member to {circle} by {author}" : "{member} wurde von {author} als Mitglied zu {circle} hinzugefügt",
    "You added {external} to {circle}" : "Du hast {external} zu {circle} hinzugefügt",
    "{external} has been added to {circle} by {author}" : "{external} wurde von {author} zu {circle} hinzugefügt",
    "You accepted {member}'s request to join {circle}" : "Du hast die Anfrage von {member}, {circle} beizutreten, angenommen",
    "Your request to join {circle} has been accepted by {author}" : "Deine Anfrage {circle} beizutreten wurde von {author} angenommen",
    "{member}'s request to join {circle} has been accepted by {author}" : "Die Anfrage von {member}, {circle} beizutreten, wurde von {author} angenommen",
    "You left {circle}" : "Du hast {circle} verlassen",
    "{member} left {circle}" : "{member} hat {circle} verlassen",
    "You declined the invitation to join {circle}" : "Du hast die Einladung {circle} beizutreten abgelehnt",
    "{member} declined an invitation to join {circle}" : "{member} hat es abgelehnt {circle} beizutreten",
    "You cancelled your request to join {circle}" : "Du hast deine Anfrage  {circle} beizutreten zurückgezogen",
    "{member} cancelled a request to join {circle}" : "{member} hat die Anfrage {circle} beizutreten abgebrochen",
    "You have been removed from {circle} by {author}" : "Du wurdest von {author} aus {circle} entfernt",
    "{member} has been removed from {circle} by {author}" : "{member} wurde von {author} aus {circle} entfernt",
    "You removed {external} from {circle}" : "Du hast {external} von {circle} entfernt",
    "{external} has been removed from {circle} by {author}" : "{external} wurde von {author} von {circle} entfernt",
    "You cancelled {member}'s invitation to join {circle}" : "Du hast die Einladung an {member} {circle} beizutreten zurückgezogen",
    "Your invitation to join {circle} has been cancelled by {author}" : "Deine Einladung {circle} beizutreten wurde von {author} zurückgezogen",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} hat die Einladung an {member} {circle} beizutreten zurückgezogen",
    "You dismissed {member}'s request to join {circle}" : "Du hast die Anfrage von {member}, {circle} beizutreten, abgelehnt",
    "Your request to join {circle} has been dismissed by {author}" : "Deine Anfrage {circle} beizutreten wurde von {author} abgelehnt",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Die Anfrage von {member}, {circle} beizutreten, wurde von {author} abgelehnt",
    "You invited {member} to join {circle}" : "Du hast {member} eingeladen {circle} beizutreten",
    "You have been invited to join {circle} by {author}" : "Du wurdest von {author} eingeladen {circle} beizutreten",
    "{member} has been invited to join {circle} by {author}" : "{member} wurde von {author} eingeladen {circle} beizutreten",
    "You changed {member}'s level in {circle} to %1$s" : "Du hast den Rang von {member}  in {circle} zu %1$s geändert",
    "{author} changed your level in {circle} to %1$s" : "{author} hat deinen Rang in {circle} zu %1$s geändert",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} hat den Rang von {member} in {circle} zu %1$s geändert",
    "You sent a request to join {circle}" : "Du hast eine Anfrage gestellt in {circle} aufgenommen zu werden",
    "{member} sent a request to join {circle}" : "{member} hat eine Anfrage gestellt in {circle} aufgenommen zu werden",
    "You are the new owner of {circle}" : "Du bist der neue Eigentümer von {circle}",
    "{member} is the new owner of {circle}" : "{member} ist der neue Eigentümer von {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Bei Ereignissen in einem <strong>Team</strong>, in dem du Mitglied bist",
    "Any important event in a <strong>team</strong> you are moderating" : "Jeder wichtige Termin in einem <strong>Team</strong>, das du moderierst",
    "On global events happening in any <strong>team</strong>" : "Bei globalen Ereignissen, in einem beliebigen <strong>Team</strong>",
    "Single" : "Einzeln",
    "Personal" : "Persönlich",
    "System" : "System",
    "Visible" : "Sichtbar",
    "Open" : "Offen",
    "Invite" : "Einladen",
    "Join request" : "Beitrittsanfrage",
    "Friends" : "Freunde",
    "Password protected" : "Passwortgeschützt",
    "No Owner" : "Kein Besitzer",
    "Hidden" : "Versteckt",
    "Backend" : "Backend",
    "Local" : "Lokal",
    "Root" : "Root",
    "Team invite" : "Teameinladung",
    "Federated" : "Federated",
    "Mount point" : "Einhängepunkt",
    "Nextcloud Account" : "Nextcloud-Konto",
    "Nextcloud Group" : "Nextcloud-Gruppe",
    "Email address" : "E-Mail-Adresse",
    "Contact" : "Kontakt",
    "Circle" : "Kreis",
    "Nextcloud App" : "Nextcloud-App",
    "Member" : "Mitglied",
    "Moderator" : "Moderator",
    "Admin" : "Administration",
    "Owner" : "Eigentümer",
    "%s shared »%s« with you." : "%s hat »%s« mit dir geteilt.",
    "%s shared »%s« with \"%s\"." : "%s hat »%s« mit \"%s\" geteilt.",
    "%s on %s" : "%s in %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s hat »%2$s« mit dir geteilt.\nDu solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s hat »%2$s« mit dir geteilt. Du solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben. ",
    "Password to access »%1$s« shared to you by %2$s" : "Das Passwort zum Zugriff auf %1$s wurde dir von  %2$s mitgetelt.",
    "Password to access »%s«" : "Passwort um auf »%s« zu zugreifen",
    "It is protected with the following password:" : "Dies ist mit dem folgendem Passwort geschützt:",
    "%1$s via %2$s" : "%1$s über %2$s",
    "Click the button below to open it." : "Zum Öffnen auf die untenstehende Schaltfläche klicken.",
    "Open »%s«" : "Öffne »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s hat mehrere Dateien mit dir geteilt.\nDu solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s hat mehrere Dateien mit dir geteilt. Du solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben. ",
    "Password to access files shared to you by %1$s" : "Passwort für den Zugriff auf die von %1$s für dich freigegebenen Dateien",
    "Password to access files" : "Passwort für den Dateizugriff",
    "%s shared multiple files with \"%s\"." : "%s hat mehrere Dateien mit \"%s\" geteilt.",
    "%s shared multiple files with you." : "%s hat mehrere Dateien mit dir geteilt.",
    "Boot up" : "Hochfahren",
    "Nextcloud Initialization" : "Nextcloud-Initialisierung",
    "Circles App Initialization" : "Kreise-App-Initialisierung",
    "Fresh installation status" : "Aktueller Initialisierungsstatus",
    "Building Local Database" : "Lokale Datenbank wird erstellt",
    "Testing Basic Circle Creation" : "Testen der grundlegenden Kreiserstellung",
    "Adding local users and moderators" : "Lokale Benutzer und Moderatoren werden hinzugefügt",
    "Show all teams" : "Alle Teams anzeigen",
    "Create a new team" : "Ein neues Team erstellen",
    "Files" : "Dateien",
    "This feature is not available for personal circles" : "Diese Funktion steht für persönliche Kreise nicht zur Verfügung",
    "The team is not federated" : "Das Team ist nicht federiert",
    "You cannot join this team" : "Du kannst diesem Team nicht beitreten",
    "This member is not a moderator" : "Dieses Mitglied ist kein Moderator",
    "Insufficient privileges" : "Nicht ausreichende Berechtigungen ",
    "This member does not exist" : "Dieses Mitglied existiert nicht",
    "This member is the owner of the team" : "Dieses Mitglied besitzt das Team",
    "Level cannot be changed for this type of member" : "Berechtigungsstufe kann für diesen Mitgliedstyp nicht geändert werden",
    "You are already a member of this circle" : "Du bist bereits Mitglied dieses Kreises",
    "You have been blocked from this circle" : "Du wurdest für diesen Kreis blockiert",
    "The account is already a member of this circle" : "Dieses Konto ist bereits Mitglied dieses Kreises",
    "The account has already been invited into this circle" : "Dieser Benutzer wurde bereits zu diesem Kreis eingeladen.",
    "%s (Team owned by %s)" : "%s (Team im Besitz von %s)",
    "You are now a member of the Team \"%2$s\"" : "Du bist jetzt Mitglied des Teams \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Du wurdest von %1$s zum Team \"%2$s\" eingeladen",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s hat eine Mitgliedschaftsanfrage für das Team \"%2$s\" gesendet",
    "Accept" : "Annehmen",
    "Refuse" : "Ablehnen",
    "Leave the team" : "Das Team verlassen",
    "%s" : "%s",
    "Personal team" : "Persönliches Team",
    "%s owned by %s" : "%s gehört %s",
    "You have no permission to create a new team" : "Du hast nicht die Berechtigung, ein neues Team zu erstellen",
    "%s shared a file with \"%s\"." : "%s hat eine Datei mit \"%s\" geteilt",
    "%s shared a file with you." : "%s hat eine Datei mit dir geteilt.",
    "%1$s shared %2$s with %3$s" : "%1$s hat %2$s mit %3$s geteilt",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s hat %2$s mit \"%3$s\" geteilt",
    "Open %s" : "%s öffnen",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s hat einen Inhalt mit dir geteilt.\nDu solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s hat einen Inhalt mit dir geteilt. Du solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.",
    "Password to access content shared with you by %1$s" : "Passwort für den Zugriff auf den Inhalt, der von %1$s mit dir geteilt wurde.",
    "Password to access content" : "Passwort für den Zugriff auf den Inhalt",
    "This item is already shared with this team" : "Dieses Element wurde bereits mit diesem Team geteilt",
    "Bring cloud-users closer together." : "Bringe Cloudnutzer näher zueinander.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Mittels Teams können Personen ihre eigenen Gruppen mit Personen/Kollegen/Freunden erstellen.\nDiese Personengruppen können dann von jeder anderen App zum Teilen verwendet werden.",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : " Keine Einträge in diesem Ordner gefunden ",
    "Name" : "Name",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "Teams' files" : "Team-Dateien",
    "Select team to filter by" : "Team auswählen, nach dem gefiltert werden soll",
    "No teams found" : "Keine Teams gefunden",
    "Please select teams to filter by" : "Bitte wähle Teams, nach denen gefiltert werden soll",
    "No files found for the selected teams" : "Keine Dateien für die ausgewählten Teams gefunden",
    "Shared to Circles" : "Geteilt mit Kreisen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/de.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Du hast das Team {circle} erstellt",
    "{author} created the team {circle}" : "{author} hat das Team {circle} erstellt",
    "You deleted {circle}" : "Du hast {circle} gelöscht",
    "{author} deleted {circle}" : "{author} hat {circle} gelöscht",
    "You made {member} join {circle}" : "Du hast {member} {circle} beitreten lassen.",
    "{author} made {member} join {circle}" : "{author} hat {member} {circle} beitreten lassen",
    "You added team {member} as member to {circle}" : "Du hast das Team {member} als Mitglied zu {circle} hinzugefügt",
    "{author} added team {member} as member to {circle}" : "{author} hat das Team {member} als Mitglied zu {circle} hinzugefügt",
    "You made {member} leave {circle}" : "Du hast {member} aus {circle} entfernt",
    "{author} made {member} leave {circle}" : "{author} hat {member} aus {circle} entfernt",
    "You removed {member} from {circle}" : "Du hast {member} aus {circle} entfernt",
    "{author} removed {member} from {circle}" : "{author} hat {member} aus {circle} entfernt",
    "You joined {circle}" : "Du bist dem {circle} beigetreten",
    "{member} joined {circle}" : "{member} ist {circle} beigetreten",
    "You accepted the invitation to join {circle}" : "Du hast die Einladung angenommen {circle} beizutreten",
    "{member} accepted the invitation to join {circle}" : "{member} hat die Einladung angenommen {circle} beizutreten",
    "You added {member} as member to {circle}" : "Du hast {member} dem Kreis {circle} hinzugefügt",
    "You have been added as member to {circle} by {author}" : "Du wurdest von {author} als Mitglied zu {circle} hinzugefügt",
    "{member} has been added as member to {circle} by {author}" : "{member} wurde von {author} als Mitglied zu {circle} hinzugefügt",
    "You added {external} to {circle}" : "Du hast {external} zu {circle} hinzugefügt",
    "{external} has been added to {circle} by {author}" : "{external} wurde von {author} zu {circle} hinzugefügt",
    "You accepted {member}'s request to join {circle}" : "Du hast die Anfrage von {member}, {circle} beizutreten, angenommen",
    "Your request to join {circle} has been accepted by {author}" : "Deine Anfrage {circle} beizutreten wurde von {author} angenommen",
    "{member}'s request to join {circle} has been accepted by {author}" : "Die Anfrage von {member}, {circle} beizutreten, wurde von {author} angenommen",
    "You left {circle}" : "Du hast {circle} verlassen",
    "{member} left {circle}" : "{member} hat {circle} verlassen",
    "You declined the invitation to join {circle}" : "Du hast die Einladung {circle} beizutreten abgelehnt",
    "{member} declined an invitation to join {circle}" : "{member} hat es abgelehnt {circle} beizutreten",
    "You cancelled your request to join {circle}" : "Du hast deine Anfrage  {circle} beizutreten zurückgezogen",
    "{member} cancelled a request to join {circle}" : "{member} hat die Anfrage {circle} beizutreten abgebrochen",
    "You have been removed from {circle} by {author}" : "Du wurdest von {author} aus {circle} entfernt",
    "{member} has been removed from {circle} by {author}" : "{member} wurde von {author} aus {circle} entfernt",
    "You removed {external} from {circle}" : "Du hast {external} von {circle} entfernt",
    "{external} has been removed from {circle} by {author}" : "{external} wurde von {author} von {circle} entfernt",
    "You cancelled {member}'s invitation to join {circle}" : "Du hast die Einladung an {member} {circle} beizutreten zurückgezogen",
    "Your invitation to join {circle} has been cancelled by {author}" : "Deine Einladung {circle} beizutreten wurde von {author} zurückgezogen",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} hat die Einladung an {member} {circle} beizutreten zurückgezogen",
    "You dismissed {member}'s request to join {circle}" : "Du hast die Anfrage von {member}, {circle} beizutreten, abgelehnt",
    "Your request to join {circle} has been dismissed by {author}" : "Deine Anfrage {circle} beizutreten wurde von {author} abgelehnt",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Die Anfrage von {member}, {circle} beizutreten, wurde von {author} abgelehnt",
    "You invited {member} to join {circle}" : "Du hast {member} eingeladen {circle} beizutreten",
    "You have been invited to join {circle} by {author}" : "Du wurdest von {author} eingeladen {circle} beizutreten",
    "{member} has been invited to join {circle} by {author}" : "{member} wurde von {author} eingeladen {circle} beizutreten",
    "You changed {member}'s level in {circle} to %1$s" : "Du hast den Rang von {member}  in {circle} zu %1$s geändert",
    "{author} changed your level in {circle} to %1$s" : "{author} hat deinen Rang in {circle} zu %1$s geändert",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} hat den Rang von {member} in {circle} zu %1$s geändert",
    "You sent a request to join {circle}" : "Du hast eine Anfrage gestellt in {circle} aufgenommen zu werden",
    "{member} sent a request to join {circle}" : "{member} hat eine Anfrage gestellt in {circle} aufgenommen zu werden",
    "You are the new owner of {circle}" : "Du bist der neue Eigentümer von {circle}",
    "{member} is the new owner of {circle}" : "{member} ist der neue Eigentümer von {circle}",
    "Teams" : "Teams",
    "On events happening in a <strong>team</strong> of which you are a member" : "Bei Ereignissen in einem <strong>Team</strong>, in dem du Mitglied bist",
    "Any important event in a <strong>team</strong> you are moderating" : "Jeder wichtige Termin in einem <strong>Team</strong>, das du moderierst",
    "On global events happening in any <strong>team</strong>" : "Bei globalen Ereignissen, in einem beliebigen <strong>Team</strong>",
    "Single" : "Einzeln",
    "Personal" : "Persönlich",
    "System" : "System",
    "Visible" : "Sichtbar",
    "Open" : "Offen",
    "Invite" : "Einladen",
    "Join request" : "Beitrittsanfrage",
    "Friends" : "Freunde",
    "Password protected" : "Passwortgeschützt",
    "No Owner" : "Kein Besitzer",
    "Hidden" : "Versteckt",
    "Backend" : "Backend",
    "Local" : "Lokal",
    "Root" : "Root",
    "Team invite" : "Teameinladung",
    "Federated" : "Federated",
    "Mount point" : "Einhängepunkt",
    "Nextcloud Account" : "Nextcloud-Konto",
    "Nextcloud Group" : "Nextcloud-Gruppe",
    "Email address" : "E-Mail-Adresse",
    "Contact" : "Kontakt",
    "Team" : "Team",
    "Nextcloud App" : "Nextcloud-App",
    "Teams App" : "Teams-App",
    "Admin Command Line" : "Administrations-Befehlszeile",
    "Member" : "Mitglied",
    "Moderator" : "Moderator",
    "Admin" : "Administration",
    "Owner" : "Eigentümer",
    "%s shared »%s« with you." : "%s hat »%s« mit dir geteilt.",
    "%s shared »%s« with \"%s\"." : "%s hat »%s« mit \"%s\" geteilt.",
    "%s on %s" : "%s in %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s hat »%2$s« mit dir geteilt.\nDu solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s hat »%2$s« mit dir geteilt. Du solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben. ",
    "Password to access »%1$s« shared to you by %2$s" : "Das Passwort zum Zugriff auf %1$s wurde dir von  %2$s mitgetelt.",
    "Password to access »%s«" : "Passwort um auf »%s« zu zugreifen",
    "It is protected with the following password:" : "Dies ist mit folgendem Passwort geschützt:",
    "%1$s via %2$s" : "%1$s über %2$s",
    "Click the button below to open it." : "Zum Öffnen auf die untenstehende Schaltfläche klicken.",
    "Open »%s«" : "Öffne »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s hat mehrere Dateien mit dir geteilt.\nDu solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s hat mehrere Dateien mit dir geteilt. Du solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben. ",
    "Password to access files shared to you by %1$s" : "Passwort für den Zugriff auf die von %1$s für dich freigegebenen Dateien",
    "Password to access files" : "Passwort für den Dateizugriff",
    "%s shared multiple files with \"%s\"." : "%s hat mehrere Dateien mit \"%s\" geteilt.",
    "%s shared multiple files with you." : "%s hat mehrere Dateien mit dir geteilt.",
    "Boot up" : "Hochfahren",
    "Nextcloud Initialization" : "Nextcloud-Initialisierung",
    "Circles App Initialization" : "Kreise-App-Initialisierung",
    "Fresh installation status" : "Aktueller Initialisierungsstatus",
    "Building Local Database" : "Lokale Datenbank wird erstellt",
    "Testing Basic Team Creation" : "Testen der grundlegenden Teamerstellung",
    "Adding local users and moderators" : "Lokale Benutzer und Moderatoren werden hinzugefügt",
    "Show all teams" : "Alle Teams anzeigen",
    "Create a new team" : "Ein neues Team erstellen",
    "Files" : "Dateien",
    "This feature is not available for personal teams" : "Diese Funktion steht für persönliche Teams nicht zur Verfügung",
    "The team is not federated" : "Das Team ist nicht federiert",
    "You cannot join this team" : "Du kannst diesem Team nicht beitreten",
    "This member is not a moderator" : "Dieses Mitglied ist kein Moderator",
    "Insufficient privileges" : "Nicht ausreichende Berechtigungen ",
    "This member does not exist" : "Dieses Mitglied existiert nicht",
    "This member is the owner of the team" : "Dieses Mitglied besitzt das Team",
    "Level cannot be changed for this type of member" : "Berechtigungsstufe kann für diesen Mitgliedstyp nicht geändert werden",
    "You are already a member of this team" : "Du bist bereits Mitglied dieses Teams",
    "You have been blocked from this team" : "Du wurdest für dieses Team blockiert",
    "The account is already a member of this team" : "Dieses Konto ist bereits Mitglied dieses Teams",
    "The account has already been invited into this team" : "Dieses Konto wurde bereits zu diesem Team eingeladen",
    "%s (Team owned by %s)" : "%s (Team im Besitz von %s)",
    "You are now a member of the Team \"%2$s\"" : "Du bist jetzt Mitglied des Teams \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Du wurdest von %1$s zum Team \"%2$s\" eingeladen",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s hat eine Mitgliedschaftsanfrage für das Team \"%2$s\" gesendet",
    "Accept" : "Annehmen",
    "Refuse" : "Ablehnen",
    "Leave the team" : "Das Team verlassen",
    "%s" : "%s",
    "Personal team" : "Persönliches Team",
    "%s owned by %s" : "%s gehört %s",
    "You have no permission to create a new team" : "Du hast nicht die Berechtigung, ein neues Team zu erstellen",
    "%s shared a file with \"%s\"." : "%s hat eine Datei mit \"%s\" geteilt",
    "%s shared a file with you." : "%s hat eine Datei mit dir geteilt.",
    "%1$s shared %2$s with %3$s" : "%1$s hat %2$s mit %3$s geteilt",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s hat %2$s mit \"%3$s\" geteilt",
    "Open %s" : "%s öffnen",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s hat einen Inhalt mit dir geteilt.\nDu solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s hat einen Inhalt mit dir geteilt. Du solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.",
    "Password to access content shared with you by %1$s" : "Passwort für den Zugriff auf den Inhalt, der von %1$s mit dir geteilt wurde.",
    "Password to access content" : "Passwort für den Zugriff auf den Inhalt",
    "This item is already shared with this team" : "Dieses Element wurde bereits mit diesem Team geteilt",
    "Bring cloud-users closer together." : "Bringe Cloudnutzer näher zueinander.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Mittels Teams können Personen ihre eigenen Gruppen mit Personen/Kollegen/Freunden erstellen.\nDiese Personengruppen können dann von jeder anderen App zum Teilen verwendet werden.",
    "Failed to load teams" : "Teams konnten nicht geladen werden",
    "Try again" : "Nochmals versuchen",
    "No teams found" : "Keine Teams gefunden",
    "Join or create teams to see them here." : "Trete Teams bei oder erstelle welche, um sie hier angezeigt zu bekommen",
    "Create your first team" : "Erstelle dein erstes Team",
    "Loading…" : "Lade …",
    "More teams" : "Weitere Teams",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden ",
    "Name" : "Name",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "Shared to Circles" : "Geteilt mit Kreisen"
},
"nplurals=2; plural=(n != 1);");
